@@ -169,7 +169,7 @@ class Exceptions:
 
 class DynamoDBClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html)
     """
 
@@ -182,13 +182,16 @@ class DynamoDBClient(BaseClient):
         """
 
     def batch_execute_statement(
-        self, *, Statements: Sequence["BatchStatementRequestTypeDef"]
+        self,
+        *,
+        Statements: Sequence["BatchStatementRequestTypeDef"],
+        ReturnConsumedCapacity: ReturnConsumedCapacityType = ...
     ) -> BatchExecuteStatementOutputTypeDef:
         """
-        This operation allows you to perform batch reads and writes on data stored in
+        This operation allows you to perform batch reads or writes on data stored in
         DynamoDB, using PartiQL.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.batch_execute_statement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.batch_execute_statement)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#batch_execute_statement)
         """
 
@@ -202,7 +205,7 @@ class DynamoDBClient(BaseClient):
         The `BatchGetItem` operation returns the attributes of one or more items from
         one or more tables.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.batch_get_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.batch_get_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#batch_get_item)
         """
 
@@ -217,7 +220,7 @@ class DynamoDBClient(BaseClient):
         The `BatchWriteItem` operation puts or deletes multiple items in one or more
         tables.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.batch_write_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.batch_write_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#batch_write_item)
         """
 
@@ -225,7 +228,7 @@ class DynamoDBClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#can_paginate)
         """
 
@@ -233,7 +236,7 @@ class DynamoDBClient(BaseClient):
         """
         Creates a backup for an existing table.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.create_backup)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.create_backup)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#create_backup)
         """
 
@@ -243,7 +246,7 @@ class DynamoDBClient(BaseClient):
         """
         Creates a global table from an existing table.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.create_global_table)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.create_global_table)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#create_global_table)
         """
 
@@ -264,7 +267,7 @@ class DynamoDBClient(BaseClient):
         """
         The `CreateTable` operation adds a new table to your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.create_table)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.create_table)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#create_table)
         """
 
@@ -272,7 +275,7 @@ class DynamoDBClient(BaseClient):
         """
         Deletes an existing backup of a table.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.delete_backup)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.delete_backup)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#delete_backup)
         """
 
@@ -329,7 +332,7 @@ class DynamoDBClient(BaseClient):
         """
         Deletes a single item in a table by primary key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.delete_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.delete_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#delete_item)
         """
 
@@ -337,7 +340,7 @@ class DynamoDBClient(BaseClient):
         """
         The `DeleteTable` operation deletes a table and all of its items.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.delete_table)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.delete_table)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#delete_table)
         """
 
@@ -345,7 +348,7 @@ class DynamoDBClient(BaseClient):
         """
         Describes an existing backup of a table.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.describe_backup)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.describe_backup)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#describe_backup)
         """
 
@@ -356,7 +359,7 @@ class DynamoDBClient(BaseClient):
         Checks the status of continuous backups and point in time recovery on the
         specified table.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.describe_continuous_backups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.describe_continuous_backups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#describe_continuous_backups)
         """
 
@@ -367,7 +370,7 @@ class DynamoDBClient(BaseClient):
         Returns information about contributor insights, for a given table or global
         secondary index.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.describe_contributor_insights)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.describe_contributor_insights)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#describe_contributor_insights)
         """
 
@@ -375,7 +378,7 @@ class DynamoDBClient(BaseClient):
         """
         Returns the regional endpoint information.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.describe_endpoints)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.describe_endpoints)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#describe_endpoints)
         """
 
@@ -383,7 +386,7 @@ class DynamoDBClient(BaseClient):
         """
         Describes an existing table export.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.describe_export)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.describe_export)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#describe_export)
         """
 
@@ -391,7 +394,7 @@ class DynamoDBClient(BaseClient):
         """
         Returns information about the specified global table.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.describe_global_table)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.describe_global_table)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#describe_global_table)
         """
 
@@ -401,7 +404,7 @@ class DynamoDBClient(BaseClient):
         """
         Describes Region-specific settings for a global table.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.describe_global_table_settings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.describe_global_table_settings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#describe_global_table_settings)
         """
 
@@ -411,17 +414,17 @@ class DynamoDBClient(BaseClient):
         """
         Returns information about the status of Kinesis streaming.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.describe_kinesis_streaming_destination)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.describe_kinesis_streaming_destination)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#describe_kinesis_streaming_destination)
         """
 
     def describe_limits(self) -> DescribeLimitsOutputTypeDef:
         """
-        Returns the current provisioned-capacity quotas for your AWS account in a
-        Region, both for the Region as a whole and for any one DynamoDB table that you
-        create there.
+        Returns the current provisioned-capacity quotas for your Amazon Web Services
+        account in a Region, both for the Region as a whole and for any one DynamoDB
+        table that you create there.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.describe_limits)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.describe_limits)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#describe_limits)
         """
 
@@ -430,7 +433,7 @@ class DynamoDBClient(BaseClient):
         Returns information about the table, including the current status of the table,
         when it was created, the primary key schema, and any indexes on the table.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.describe_table)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.describe_table)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#describe_table)
         """
 
@@ -440,7 +443,7 @@ class DynamoDBClient(BaseClient):
         """
         Describes auto scaling settings across replicas of the global table at once.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.describe_table_replica_auto_scaling)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.describe_table_replica_auto_scaling)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#describe_table_replica_auto_scaling)
         """
 
@@ -448,7 +451,7 @@ class DynamoDBClient(BaseClient):
         """
         Gives a description of the Time to Live (TTL) status on the specified table.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.describe_time_to_live)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.describe_time_to_live)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#describe_time_to_live)
         """
 
@@ -458,7 +461,7 @@ class DynamoDBClient(BaseClient):
         """
         Stops replication from the DynamoDB table to the Kinesis data stream.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.disable_kinesis_streaming_destination)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.disable_kinesis_streaming_destination)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#disable_kinesis_streaming_destination)
         """
 
@@ -469,7 +472,7 @@ class DynamoDBClient(BaseClient):
         Starts table data replication to the specified Kinesis data stream at a
         timestamp chosen during the enable workflow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.enable_kinesis_streaming_destination)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.enable_kinesis_streaming_destination)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#enable_kinesis_streaming_destination)
         """
 
@@ -496,13 +499,14 @@ class DynamoDBClient(BaseClient):
             ]
         ] = ...,
         ConsistentRead: bool = ...,
-        NextToken: str = ...
+        NextToken: str = ...,
+        ReturnConsumedCapacity: ReturnConsumedCapacityType = ...
     ) -> ExecuteStatementOutputTypeDef:
         """
         This operation allows you to perform reads and singleton writes on data stored
         in DynamoDB, using PartiQL.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.execute_statement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.execute_statement)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#execute_statement)
         """
 
@@ -510,13 +514,14 @@ class DynamoDBClient(BaseClient):
         self,
         *,
         TransactStatements: Sequence["ParameterizedStatementTypeDef"],
-        ClientRequestToken: str = ...
+        ClientRequestToken: str = ...,
+        ReturnConsumedCapacity: ReturnConsumedCapacityType = ...
     ) -> ExecuteTransactionOutputTypeDef:
         """
         This operation allows you to perform transactional reads or writes on data
         stored in DynamoDB, using PartiQL.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.execute_transaction)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.execute_transaction)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#execute_transaction)
         """
 
@@ -536,7 +541,7 @@ class DynamoDBClient(BaseClient):
         """
         Exports table data to an S3 bucket.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.export_table_to_point_in_time)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.export_table_to_point_in_time)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#export_table_to_point_in_time)
         """
 
@@ -550,7 +555,7 @@ class DynamoDBClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#generate_presigned_url)
         """
 
@@ -587,7 +592,7 @@ class DynamoDBClient(BaseClient):
         The `GetItem` operation returns a set of attributes for the item with the given
         primary key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.get_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.get_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#get_item)
         """
 
@@ -602,9 +607,9 @@ class DynamoDBClient(BaseClient):
         BackupType: BackupTypeFilterType = ...
     ) -> ListBackupsOutputTypeDef:
         """
-        List backups associated with an AWS account.
+        List backups associated with an Amazon Web Services account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.list_backups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.list_backups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#list_backups)
         """
 
@@ -615,7 +620,7 @@ class DynamoDBClient(BaseClient):
         Returns a list of ContributorInsightsSummary for a table and all its global
         secondary indexes.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.list_contributor_insights)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.list_contributor_insights)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#list_contributor_insights)
         """
 
@@ -625,7 +630,7 @@ class DynamoDBClient(BaseClient):
         """
         Lists completed exports within the past 90 days.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.list_exports)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.list_exports)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#list_exports)
         """
 
@@ -635,7 +640,7 @@ class DynamoDBClient(BaseClient):
         """
         Lists all global tables that have a replica in the specified Region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.list_global_tables)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.list_global_tables)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#list_global_tables)
         """
 
@@ -646,7 +651,7 @@ class DynamoDBClient(BaseClient):
         Returns an array of table names associated with the current account and
         endpoint.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.list_tables)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.list_tables)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#list_tables)
         """
 
@@ -656,7 +661,7 @@ class DynamoDBClient(BaseClient):
         """
         List all tags on an Amazon DynamoDB resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.list_tags_of_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.list_tags_of_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#list_tags_of_resource)
         """
 
@@ -713,7 +718,7 @@ class DynamoDBClient(BaseClient):
         """
         Creates a new item, or replaces an old item with a new item.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.put_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.put_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#put_item)
         """
 
@@ -775,9 +780,10 @@ class DynamoDBClient(BaseClient):
         ] = ...
     ) -> QueryOutputTypeDef:
         """
-        The `Query` operation finds items based on primary key values.
+        You must provide the name of the partition key attribute and a single value for
+        that attribute.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.query)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.query)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#query)
         """
 
@@ -795,7 +801,7 @@ class DynamoDBClient(BaseClient):
         """
         Creates a new table from an existing backup.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.restore_table_from_backup)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.restore_table_from_backup)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#restore_table_from_backup)
         """
 
@@ -817,7 +823,7 @@ class DynamoDBClient(BaseClient):
         Restores the specified table to the specified point in time within
         `EarliestRestorableDateTime` and `LatestRestorableDateTime`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.restore_table_to_point_in_time)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.restore_table_to_point_in_time)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#restore_table_to_point_in_time)
         """
 
@@ -881,7 +887,7 @@ class DynamoDBClient(BaseClient):
         The `Scan` operation returns one or more items and item attributes by accessing
         every item in a table or a secondary index.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.scan)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.scan)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#scan)
         """
 
@@ -889,7 +895,7 @@ class DynamoDBClient(BaseClient):
         """
         Associate a set of tags with an Amazon DynamoDB resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#tag_resource)
         """
 
@@ -904,7 +910,7 @@ class DynamoDBClient(BaseClient):
         items from one or more tables (but not from indexes) in a single account and
         Region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.transact_get_items)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.transact_get_items)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#transact_get_items)
         """
 
@@ -920,7 +926,7 @@ class DynamoDBClient(BaseClient):
         `TransactWriteItems` is a synchronous write operation that groups up to 25
         action requests.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.transact_write_items)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.transact_write_items)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#transact_write_items)
         """
 
@@ -928,7 +934,7 @@ class DynamoDBClient(BaseClient):
         """
         Removes the association of tags from an Amazon DynamoDB resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#untag_resource)
         """
 
@@ -942,7 +948,7 @@ class DynamoDBClient(BaseClient):
         `UpdateContinuousBackups` enables or disables point in time recovery for the
         specified table.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.update_continuous_backups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.update_continuous_backups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#update_continuous_backups)
         """
 
@@ -956,7 +962,7 @@ class DynamoDBClient(BaseClient):
         """
         Updates the status for contributor insights for a specific table or index.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.update_contributor_insights)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.update_contributor_insights)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#update_contributor_insights)
         """
 
@@ -966,7 +972,7 @@ class DynamoDBClient(BaseClient):
         """
         Adds or removes replicas in the specified global table.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.update_global_table)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.update_global_table)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#update_global_table)
         """
 
@@ -985,7 +991,7 @@ class DynamoDBClient(BaseClient):
         """
         Updates settings for a global table.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.update_global_table_settings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.update_global_table_settings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#update_global_table_settings)
         """
 
@@ -1045,7 +1051,7 @@ class DynamoDBClient(BaseClient):
         Edits an existing item's attributes, or adds a new item to the table if it does
         not already exist.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.update_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.update_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#update_item)
         """
 
@@ -1065,7 +1071,7 @@ class DynamoDBClient(BaseClient):
         Modifies the provisioned throughput settings, global secondary indexes, or
         DynamoDB Streams settings for a given table.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.update_table)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.update_table)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#update_table)
         """
 
@@ -1080,7 +1086,7 @@ class DynamoDBClient(BaseClient):
         """
         Updates auto scaling settings on your global tables at once.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.update_table_replica_auto_scaling)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.update_table_replica_auto_scaling)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#update_table_replica_auto_scaling)
         """
 
@@ -1091,21 +1097,21 @@ class DynamoDBClient(BaseClient):
         The `UpdateTimeToLive` method enables or disables Time to Live (TTL) for the
         specified table.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Client.update_time_to_live)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Client.update_time_to_live)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#update_time_to_live)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_backups"]) -> ListBackupsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#listbackupspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_tables"]) -> ListTablesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#listtablespaginator)
         """
 
@@ -1114,34 +1120,34 @@ class DynamoDBClient(BaseClient):
         self, operation_name: Literal["list_tags_of_resource"]
     ) -> ListTagsOfResourcePaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#listtagsofresourcepaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["query"]) -> QueryPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Paginator.Query)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Paginator.Query)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#querypaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["scan"]) -> ScanPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Paginator.Scan)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Paginator.Scan)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#scanpaginator)
         """
 
     @overload
     def get_waiter(self, waiter_name: Literal["table_exists"]) -> TableExistsWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Waiter.TableExists)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Waiter.TableExists)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/waiters.html#tableexistswaiter)
         """
 
     @overload
     def get_waiter(self, waiter_name: Literal["table_not_exists"]) -> TableNotExistsWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/dynamodb.html#DynamoDB.Waiter.TableNotExists)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/dynamodb.html#DynamoDB.Waiter.TableNotExists)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/waiters.html#tablenotexistswaiter)
         """
